aboutsummaryrefslogtreecommitdiff
path: root/gdb/ppc-tdep.h
diff options
context:
space:
mode:
authorJim Blandy <jimb@codesourcery.com>2004-05-10 18:58:44 +0000
committerJim Blandy <jimb@codesourcery.com>2004-05-10 18:58:44 +0000
commit7bcda025ec2abe0f8a8583a11083ee06e6b46d86 (patch)
tree7a1e525f38b21b59a15c914efab7c369e0b95201 /gdb/ppc-tdep.h
parentcca0d3b0302614184413157e253136ebf3aa5295 (diff)
downloadgdb-7bcda025ec2abe0f8a8583a11083ee06e6b46d86.zip
gdb-7bcda025ec2abe0f8a8583a11083ee06e6b46d86.tar.gz
gdb-7bcda025ec2abe0f8a8583a11083ee06e6b46d86.tar.bz2
Back out change. The NetBSD changes need Jason Thorpe's approval, but
he hasn't reviewed it yet.
Diffstat (limited to 'gdb/ppc-tdep.h')
-rw-r--r--gdb/ppc-tdep.h8
1 files changed, 2 insertions, 6 deletions
diff --git a/gdb/ppc-tdep.h b/gdb/ppc-tdep.h
index a47fdfc..9bfb68e 100644
--- a/gdb/ppc-tdep.h
+++ b/gdb/ppc-tdep.h
@@ -74,8 +74,8 @@ enum return_value_convention ppc64_sysv_abi_return_value (struct gdbarch *gdbarc
/* From rs6000-tdep.c... */
int altivec_register_p (int regno);
-/* Return non-zero if the architecture described by GDBARCH has
- floating-point registers (f0 --- f31 and fpscr). */
+/* Return non-zero when the architecture has an FPU (or at least when
+ the ABI is using the FPU). */
int ppc_floating_point_unit_p (struct gdbarch *gdbarch);
/* Register set description. */
@@ -150,13 +150,9 @@ struct gdbarch_tdep
int ppc_lr_regnum; /* Link register */
int ppc_ctr_regnum; /* Count register */
int ppc_xer_regnum; /* Integer exception register */
-
- /* On PPC and RS6000 variants that have no floating-point
- registers, the next two members will be -1. */
int ppc_fp0_regnum; /* floating-point register 0 */
int ppc_fpscr_regnum; /* Floating point status and condition
register */
-
int ppc_mq_regnum; /* Multiply/Divide extension register */
int ppc_vr0_regnum; /* First AltiVec register */
int ppc_vrsave_regnum; /* Last AltiVec register */